==> uimaj-3.2.0-source-release.zip: uimaj-3.2.0/uimaj-ep-cas-editor-ide/src/main/java/org/apache/uima/caseditor/ide/CasEditorIdePreferencePage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.caseditor.ide;

import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

/**
 * Preference page to manage preferences for the ide plugin.
 */
public class CasEditorIdePreferencePage extends FieldEditorPreferencePage
        implements IWorkbenchPreferencePage {

  public CasEditorIdePreferencePage() {
    setPreferenceStore(CasEditorIdePlugin.getDefault().getPreferenceStore());
    setDescription("Cas Editor Ide Preferences.");
  }

  @Override
  protected void createFieldEditors() {
   
    // should the editor use the last selected type system to open the cas?
    BooleanFieldEditor mEditorRememberTypesystem = new BooleanFieldEditor(CasEditorIdePreferenceConstants.CAS_EDITOR_REMEMBER_TYPESYSTEM,
        "Use the previously selected type system to open a CAS", getFieldEditorParent());
    addField(mEditorRememberTypesystem);
  }

  public void init(IWorkbench workbench) {
  }
}

==> uimaj-3.6.1-source-release.zip: uimaj-3.6.1/uimaj-ep-cas-editor-ide/src/main/java/org/apache/uima/caseditor/ide/CasEditorIdePreferencePage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.caseditor.ide;

import org.eclipse.jface.preference.BooleanFieldEditor;
import org.eclipse.jface.preference.FieldEditorPreferencePage;
import org.eclipse.ui.IWorkbench;
import org.eclipse.ui.IWorkbenchPreferencePage;

/**
 * Preference page to manage preferences for the ide plugin.
 */
public class CasEditorIdePreferencePage extends FieldEditorPreferencePage
        implements IWorkbenchPreferencePage {

  public CasEditorIdePreferencePage() {
    setPreferenceStore(CasEditorIdePlugin.getDefault().getPreferenceStore());
    setDescription("Cas Editor Ide Preferences.");
  }

  @Override
  protected void createFieldEditors() {

    // should the editor use the last selected type system to open the cas?
    BooleanFieldEditor mEditorRememberTypesystem = new BooleanFieldEditor(
            CasEditorIdePreferenceConstants.CAS_EDITOR_REMEMBER_TYPESYSTEM,
            "Use the previously selected type system to open a CAS", getFieldEditorParent());
    addField(mEditorRememberTypesystem);
  }

  @Override
  public void init(IWorkbench workbench) {
  }
}
